<?php
/**
 * Register custom theme menus
 * This file is loaded via the 'after_setup_theme' hook at priority '10'
 *
 * @package    Hoot
 * @subpackage Divogue
 */

/* Register custom menus. */
add_action( 'init', 'hoot_base_register_menus', 5 );

/**
 * Registers nav menu locations.
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hoot_base_register_menus() {
	register_nav_menu( 'primary', _x( 'Primary Navigation', 'nav menu location', 'divogue' ) );
}

/**
 * Apply Walker to Nav Menu displayed in frontend
 *
 * @since 1.0
 * @access public
 * @param array $args
 * @return array
 */
add_filter( 'wp_nav_menu_args', 'hoot_theme_wp_nav_menu_walker', 98 );
function hoot_theme_wp_nav_menu_walker( $args ){
	// Apply walker if none already exists
	// if ( class_exists( 'Hoot_Theme_Nav_Menu' ) && empty( $args['walker'] ) ) {
	if ( class_exists( 'Hoot_Theme_Nav_Menu' ) ) {
		$args['walker'] = new Hoot_Theme_Nav_Menu;
	}
	return $args;
}

/**
 * Walker Class for Displaying Nav Menu using 'wp_nav_menu()' (sync WP.4.9.8)
 * Extends Walker_Nav_Menu class in core url('/wp-includes/class-walker-nav-menu.php')
 * @see http://codex.wordpress.org/Function_Reference/wp_nav_menu#Using_a_Custom_Walker_Function
 * 
 * Alternately, for a more customized display, we can extend the grandparent 'Walker' class instead (copy and
 * modify code of 'Walker_Nav_Menu' class)
 * class Hoot_Theme_Nav_Menu extends Walker`
 *
 * @since 1.0
 */
class Hoot_Theme_Nav_Menu extends Walker_Nav_Menu {

	/**
	 * Starts the element output.
	 *
	 * @since WP.3.0.0
	 * @since WP.4.4.0 The {@see 'nav_menu_item_args'} filter was added.
	 *
	 * @see Walker::start_el()
	 *
	 * @param string   $output Used to append additional content (passed by reference).
	 * @param WP_Post  $item   Menu item data object.
	 * @param int      $depth  Depth of menu item. Used for padding.
	 * @param stdClass $args   An object of wp_nav_menu() arguments.
	 * @param int      $id     Current item ID.
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
			$t = '';
			$n = '';
		} else {
			$t = "\t";
			$n = "\n";
		}
		$indent = ( $depth ) ? str_repeat( $t, $depth ) : '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		/**
		 * Filters the arguments for a single nav menu item.
		 *
		 * @since WP.4.4.0
		 *
		 * @param stdClass $args  An object of wp_nav_menu() arguments.
		 * @param WP_Post  $item  Menu item data object.
		 * @param int      $depth Depth of menu item. Used for padding.
		 */
		$args = apply_filters( 'nav_menu_item_args', $args, $item, $depth );

		/**
		 * Filter the CSS class(es) applied to a menu item's list item element.
		 *
		 * @since WP.3.0.0
		 * @since WP.4.1.0 The `$depth` parameter was added.
		 *
		 * @param array  $classes The CSS classes that are applied to the menu item's `<li>` element.
		 * @param object $item    The current menu item.
		 * @param array  $args    An array of {@see wp_nav_menu()} arguments.
		 * @param int    $depth   Depth of menu item. Used for padding.
		 */
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		/**
		 * Filter the ID applied to a menu item's list item element.
		 *
		 * @since WP.3.0.1
		 * @since WP.4.1.0 The `$depth` parameter was added.
		 *
		 * @param string $menu_id The ID that is applied to the menu item's `<li>` element.
		 * @param object $item    The current menu item.
		 * @param array  $args    An array of {@see wp_nav_menu()} arguments.
		 * @param int    $depth   Depth of menu item. Used for padding.
		 */
		$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args, $depth );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $class_names .'>';

		$atts = array();
		$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
		$atts['target'] = ! empty( $item->target )     ? $item->target     : '';
		$atts['rel']    = ! empty( $item->xfn )        ? $item->xfn        : '';
		$atts['href']   = ! empty( $item->url )        ? $item->url        : '';

		/**
		 * Filter the HTML attributes applied to a menu item's anchor element.
		 *
		 * @since WP.3.6.0
		 * @since WP.4.1.0 The `$depth` parameter was added.
		 *
		 * @param array $atts {
		 *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
		 *
		 *     @type string $title  Title attribute.
		 *     @type string $target Target attribute.
		 *     @type string $rel    The rel attribute.
		 *     @type string $href   The href attribute.
		 * }
		 * @param object $item  The current menu item.
		 * @param array  $args  An array of {@see wp_nav_menu()} arguments.
		 * @param int    $depth Depth of menu item. Used for padding.
		 */
		$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

		$attributes = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}

		/** This filter is documented in wp-includes/post-template.php */
		$title = apply_filters( 'the_title', $item->title, $item->ID );

		/**
		 * Filters a menu item's title.
		 *
		 * @since WP.4.4.0
		 *
		 * @param string   $title The menu item's title.
		 * @param WP_Post  $item  The current menu item.
		 * @param stdClass $args  An object of wp_nav_menu() arguments.
		 * @param int      $depth Depth of menu item. Used for padding.
		 */
		$title = apply_filters( 'nav_menu_item_title', $title, $item, $args, $depth );

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';



		// $item_output .= $args->link_before . $title . $args->link_after;
		/** MODIFIED HOOT THEME CODE **/
		$item_output = apply_filters( 'hoot_theme_nav_walker_menu_item_start', $item_output, $item, $depth ); // Possible location to add other code
		$item_output .= $args->link_before;
		$item_output .= '<span class="menu-title">';
		if ( class_exists( 'HybridExtend_Megamenu_Walker' ) ) {
			$hybridextend_megamenu_item = get_post_meta( $item->ID, '_menu-item-hybridextend_megamenu', true );
			$item_output .= apply_filters( 'hybridextend_megamenu_displayitem', '', $hybridextend_megamenu_item, $item, $depth );
		}
		$item_output .= $title . '</span>';
		if ( !empty( $item->description ) )
			$item_output .= '<span class="menu-description">' . $item->description . '</span>';
		$item_output .= $args->link_after;
		$item_output = apply_filters( 'hoot_theme_nav_walker_menu_item_end', $item_output, $item, $depth ); // Possible location to add other code



		$item_output .= '</a>';
		$item_output .= $args->after;

		/**
		 * Filter a menu item's starting output.
		 *
		 * The menu item's starting output only includes `$args->before`, the opening `<a>`,
		 * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
		 * no filter for modifying the opening and closing `<li>` for a menu item.
		 *
		 * @since WP.3.0.0
		 *
		 * @param string $item_output The menu item's starting HTML output.
		 * @param object $item        Menu item data object.
		 * @param int    $depth       Depth of menu item. Used for padding.
		 * @param array  $args        An array of {@see wp_nav_menu()} arguments.
		 */
		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}

}